@@ -2,9 +2,6 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from future import standard_library
-
-standard_library.install_aliases()
 import os
 import os.path as op
 import subprocess
@@ -28,7 +25,7 @@ def make_splunkhome_path(parts):
     # Check that we haven't escaped from intended parent directories.
     if os.path.relpath(fullpath, basepath)[0:2] == "..":
         raise ValueError(
-            'Illegal escape from parent directory "%s": %s' % (basepath, fullpath)
+            'Illegal escape from parent directory "{}": {}'.format(basepath, fullpath)
         )
 
     return fullpath
