@@ -2,8 +2,6 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from builtins import range
-from builtins import object
 import os.path as op
 import os
 import json
@@ -29,7 +27,7 @@ def get_state_store(
         return FileStateStore(meta_configs, appname)
 
 
-class BaseStateStore(object):
+class BaseStateStore:
     def __init__(self, meta_configs, appname):
         self._meta_configs = meta_configs
         self._appname = appname
@@ -57,7 +55,7 @@ class StateStore(BaseStateStore):
         Don"t use other method to visit the collection if you are using
          StateStore to visit it.
         """
-        super(StateStore, self).__init__(meta_configs, appname)
+        super().__init__(meta_configs, appname)
 
         # State cache is a dict from _key to value
         self._states_cache = {}
@@ -133,7 +131,7 @@ class FileStateStore(BaseStateStore):
         server_uri etc
         """
 
-        super(FileStateStore, self).__init__(meta_configs, appname)
+        super().__init__(meta_configs, appname)
 
     def update_state(self, key, states):
         """
@@ -178,7 +176,7 @@ class CachedFileStateStore(BaseStateStore):
         server_uri etc
         """
 
-        super(CachedFileStateStore, self).__init__(meta_configs, appname)
+        super().__init__(meta_configs, appname)
         self._states_cache = {}  # item: time, dict
         self._states_cache_lmd = {}  # item: time, dict
         self.max_cache_seconds = max_cache_seconds
