@@ -2,11 +2,10 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from builtins import object
 import threading
 
 
-class Timer(object):
+class Timer:
     """
     Timer wraps the callback and timestamp related stuff
     """
@@ -61,6 +60,18 @@ class Timer(object):
     def __lt__(self, other):
         return self.__cmp__(other) == -1
 
+    def __gt__(self, other):
+        return self.__cmp__(other) == 1
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __le__(self, other):
+        return self.__lt__(other) or self.__eq__(other)
+
+    def __ge__(self, other):
+        return self.__gt__(other) or self.__eq__(other)
+
     def __hash__(self):
         return self.ident()
 
