@@ -6,10 +6,6 @@
 A timer queue implementation
 """
 
-from future import standard_library
-
-standard_library.install_aliases()
-from builtins import object
 import threading
 import queue
 from time import time
@@ -19,7 +15,7 @@ from splunktalib.timer import Timer
 from splunktalib.common import log
 
 
-class TimerQueue(object):
+class TimerQueue:
     """
     A timer queue implementation, runs a separate thread to handle timers
     """
